/* vim:set et sw=2 cin cino=t0,f0,(0,{s,>2s,n-s,^-s,e2s: */
/*
 * Copyright © 2016 Collabora Ltd.
 *
 * SPDX-License-Identifier: MPL-2.0
 * This Source Code Form is subject to the terms of the Mozilla Public
 * License, v. 2.0. If a copy of the MPL was not distributed with this
 * file, You can obtain one at http://mozilla.org/MPL/2.0/.
 */

#ifndef __FROME_CONSTANTS_H__
#define __FROME_CONSTANTS_H__

#include <glib-object.h>

G_BEGIN_DECLS

#define FROME_BUS_NAME "org.apertis.Frome"
#define FROME_PATH "/org/apertis/Frome"

#define FROME_ACCOUNT_MANAGER_BUS_NAME "Frome.AccountMgr"
#define FROME_ACCOUNT_MANAGER_PATH "/Frome/AccountMgr"
#define FROME_ACCOUNT_MANAGER_IFACE "Frome.AccountMgr"

#define FROME_DOWNLOAD_MANAGER_BUS_NAME "Frome.DnldMgr"
#define FROME_DOWNLOAD_MANAGER_PATH "/Frome/DnldMgr"
#define FROME_DOWNLOAD_MANAGER_IFACE "Frome.DnldMgr"

#define DEFAULT_WEB_SERVER_URL "http://rbcm-portal-prototype.bosch.com/boschstore/adit_bosch_api.php"

typedef enum {
  ACCOUNT_TYPE_DEVEL = 1,
  ACCOUNT_TYPE_RELEASE,
  ACCOUNT_TYPE_BOTH,
} AccountType;

typedef enum {
  APP_STATE_INITIAL,
  APP_STATE_PURCHASED,
  APP_STATE_DOWNLOAD_READY,
  APP_STATE_DOWNLOADING,
  APP_STATE_INSTALLING,
  APP_STATE_INSTALLED,
  APP_STATE_UPDATE,
  APP_STATE_UNINSTALLED
} AppState;

typedef enum {
  APP_STATUS_INSTALLATION_SUCCESS,
  APP_STATUS_DOWNLOAD_STARTED,
  APP_STATUS_DOWNLOADING,
  APP_STATUS_DOWNLOAD_COMPLETE,
  APP_STATUS_DOWNLOADING_FATAL_ERROR,
  APP_STATUS_EXTRACTION_IN_PROGRESS,
  APP_STATUS_EXTRACTION_FAILED,
  APP_STATUS_RUNNING_INSTALL_SCRIPT,
  APP_STATUS_UNINSTALLATION_FAILED,
  APP_STATUS_CREATE_TEMP_SUBVOL,
  APP_STATUS_RENAME_TEMP_SUBVOL,
  APP_STATUS_MOUNT_SUBVOL,
  APP_STATUS_UNMOUNT_SUBVOL,
  APP_STATUS_UPGRADE_SUBVOL,
  APP_STATUS_UNINSTALL_WHILE_UPDATING,
} AppStatus;

typedef enum {
  PROCESS_TYPE_APP_INSTALL,
  PROCESS_TYPE_APP_REINSTALL,
  PROCESS_TYPE_APP_UNINSTALL,
  PROCESS_TYPE_APP_UPDATE,
  PROCESS_TYPE_APP_ROLLBACK,
  PROCESS_TYPE_APP_USB_INSTALLATION,
  PROCESS_TYPE_APP_INTERNAL_INSTALLATION,
  PROCESS_TYPE_APP_REMOVAL,
} ProcessType;

#define ROLLBACK_NOT_APPLICABLE "NA"

const gchar *app_state_to_str (AppState state);
const gchar *app_status_to_str (AppStatus status);
const gchar *process_type_to_str (ProcessType type);

/* AppstoreDownloadProgress @app_state and AppstoreDownloadStatus @app_state */
#define FROME_APPSTORE_SIG_STATE_LOADING "LOADING"
#define FROME_APPSTORE_SIG_STATE_INSTALLING "INSTALLING"
#define FROME_APPSTORE_SIG_STATE_INSTALLED "INSTALLED"
#define FROME_APPSTORE_SIG_STATE_UNINSTALLED "UNINSTALLED"
#define FROME_APPSTORE_SIG_STATE_REINSTALL "REINSTALL"

/* AppstoreDownloadStatus @status */
#define FROME_APPSTORE_DOWNLOAD_STATUS_SUCCESS "SUCCESS"
#define FROME_APPSTORE_DOWNLOAD_STATUS_FAILED "FAILED"
#define FROME_APPSTORE_DOWNLOAD_STATUS_CANCELLED "CANCELLED"

/* AppstoreDownloadStatus @result_code. The values are from the old Frome */
typedef enum {
  FROME_APPSTORE_DOWNLOAD_STATUS_RESULT_NO_ERROR = 0,
  FROME_APPSTORE_DOWNLOAD_STATUS_RESULT_ERROR_EXTRACTION_FATAL_ERROR = 5,
  FROME_APPSTORE_DOWNLOAD_STATUS_RESULT_ERROR_DOWNLOADING_APP = 37,
  FROME_APPSTORE_DOWNLOAD_STATUS_RESULT_ERROR_UPDATE_VERSION = 38,
  FROME_APPSTORE_DOWNLOAD_STATUS_RESULT_ERROR_DOWNLOAD_ABORTED_BY_USER = 40,
  FROME_APPSTORE_DOWNLOAD_STATUS_RESULT_ERROR_UNINSTALL_FAILED = 41,
  /* Not present in the old Frome */
  FROME_APPSTORE_DOWNLOAD_STATUS_RESULT_ERROR_REINSTALL_FAILED = 100,
} FromeAppstoreDownloadStatusResult;

const gchar *frome_appstore_download_status_result_to_str (FromeAppstoreDownloadStatusResult result);

G_END_DECLS

#endif /* __FROME_CONSTANTS_H__ */
